@@ -28,6 +28,7 @@
 #include <openpgp.h>
 #include <x509/rfc2818.h>	/* for MAX_CN */
 
+
 static int
 xml_add_tag (gnutls_string * xmlkey, const char *tag, const char *val)
 {
@@ -49,11 +50,24 @@ xml_add_tag (gnutls_string * xmlkey, const char *tag, const char *val)
 }
 
 
+/* Add a tag to the xml key with an unsigned integer based value.
+   We use the unsigned format, because no key attribute has a
+   negative values. */
+static int
+xml_add_tag_uint_val (gnutls_string *xmlkey, const char *tag, unsigned int val)
+{
+  char tmp[32];
+  
+  sprintf (tmp, "%lu", (unsigned long)val);
+  return xml_add_tag (xmlkey, tag, tmp);
+}
+
+
 static int
 xml_add_mpi2 (gnutls_string * xmlkey, const uint8_t * data, size_t count,
 	      const char *tag)
 {
-  char *p = NULL;
+  char *p;
   size_t i;
   int rc;
 
@@ -86,9 +100,11 @@ xml_add_mpi (gnutls_string * xmlkey, cdk_pkt_pubkey_t pk, int idx,
 {
   uint8_t buf[4096]; /* Maximal supported MPI of size 32786 bits */
   size_t nbytes;
-
+  
+  /* FIXME: we should not hardcode the buffer size. */
   nbytes = 4096;
-  cdk_pk_get_mpi (pk, idx, buf, nbytes, &nbytes, NULL);
+  if (cdk_pk_get_mpi (pk, idx, buf, nbytes, &nbytes, NULL))
+    return GNUTLS_E_INTERNAL_ERROR;
   return xml_add_mpi2 (xmlkey, buf, nbytes, tag);
 }
 
@@ -124,19 +140,10 @@ xml_add_key_mpi (gnutls_string * xmlkey, cdk_pkt_pubkey_t pk)
       if (!rc)
 	rc = xml_add_mpi (xmlkey, pk, 3, "DSA-Y");
     }
-  else if (is_ELG (pk->pubkey_algo))
-    {
-      /* FIXME: Does GnuTLS supports ElGamal? */
-      rc = xml_add_mpi (xmlkey, pk, 0, "ELG-P");
-      if (!rc)
-	rc = xml_add_mpi (xmlkey, pk, 1, "ELG-G");
-      if (!rc)
-	rc = xml_add_mpi (xmlkey, pk, 2, "ELG-Y");
-    }
   else
     return GNUTLS_E_UNWANTED_ALGORITHM;
 
-  return 0;
+  return rc;
 }
 
 
@@ -144,8 +151,8 @@ static int
 xml_add_key (gnutls_string * xmlkey, int ext, cdk_pkt_pubkey_t pk, int sub)
 {
   const char *algo, *s;
-  char keyid[16], fpr[41], tmp[32];
-  uint8_t fingerpr[20];
+  char keyid[32+1], strfpr[40+1];
+  uint8_t keyfpr[20];
   unsigned int kid[2];
   int i = 0, rc = 0;
 
@@ -159,17 +166,17 @@ xml_add_key (gnutls_string * xmlkey, int ext, cdk_pkt_pubkey_t pk, int sub)
   _gnutls_string_append_str (xmlkey, s);
 
   cdk_pk_get_keyid (pk, kid);
-  snprintf (keyid, 16, "%08lX%08lX", 
+  snprintf (keyid, 32, "%08lX%08lX", 
 	    (unsigned long)kid[0], (unsigned long)kid[1]);
   rc = xml_add_tag (xmlkey, "KEYID", keyid);
   if (rc)
     return rc;
 
-  cdk_pk_get_fingerprint (pk, fingerpr);
+  cdk_pk_get_fingerprint (pk, keyfpr);
   for (i = 0; i < 20; i++)
-    sprintf (fpr + 2 * i, "%02X", fingerpr[i]);
-  fpr[40] = '\0';
-  rc = xml_add_tag (xmlkey, "FINGERPRINT", fpr);
+    sprintf (strfpr + 2 * i, "%02X", keyfpr[i]);
+  strfpr[40] = '\0';
+  rc = xml_add_tag (xmlkey, "FINGERPRINT", strfpr);
   if (rc)
     return rc;
 
@@ -177,34 +184,28 @@ xml_add_key (gnutls_string * xmlkey, int ext, cdk_pkt_pubkey_t pk, int sub)
     algo = "DSA";
   else if (is_RSA (pk->pubkey_algo))
     algo = "RSA";
-  else if (is_ELG (pk->pubkey_algo))
-    algo = "ELG"; /* FIXME: Same here is ElGamal supported? */
   else
-    algo = "???";
+    return GNUTLS_E_UNWANTED_ALGORITHM;
   rc = xml_add_tag (xmlkey, "PKALGO", algo);
   if (rc)
     return rc;
-
-  sprintf (tmp, "%d", cdk_pk_get_nbits (pk));
-  rc = xml_add_tag (xmlkey, "KEYLEN", tmp);
+  
+  rc = xml_add_tag_uint_val (xmlkey, "KEYLEN", cdk_pk_get_nbits (pk));
   if (rc)
     return rc;
 
-  sprintf (tmp, "%lu", (unsigned long)pk->timestamp);
-  rc = xml_add_tag (xmlkey, "CREATED", tmp);
+  rc = xml_add_tag_uint_val (xmlkey, "CREATED", pk->timestamp);
   if (rc)
     return rc;
 
   if (pk->expiredate > 0)
     {
-      sprintf (tmp, "%lu", (unsigned long) pk->expiredate);
-      rc = xml_add_tag (xmlkey, "EXPIREDATE", tmp);
+      rc = xml_add_tag_uint_val (xmlkey, "EXPIREDATE", pk->expiredate);
       if (rc)
 	return rc;
     }
 
-  sprintf (tmp, "%d", pk->is_revoked);
-  rc = xml_add_tag (xmlkey, "REVOKED", tmp);
+  rc = xml_add_tag_uint_val (xmlkey, "REVOKED", pk->is_revoked);
   if (rc)
     return rc;
 
@@ -227,7 +228,6 @@ xml_add_userid (gnutls_string * xmlkey, int ext,
 		const char *dn, cdk_pkt_userid_t id)
 {
   const char *s;
-  char tmp[32];
   int rc;
 
   if (!xmlkey || !dn || !id)
@@ -245,12 +245,9 @@ xml_add_userid (gnutls_string * xmlkey, int ext,
 
   if (ext)
     {
-      sprintf (tmp, "%d", id->is_primary);
-      rc = xml_add_tag (xmlkey, "PRIMARY", tmp);
-      if (rc)
-	return rc;
-      sprintf (tmp, "%d", id->is_revoked);
-      rc = xml_add_tag (xmlkey, "REVOKED", tmp);
+      rc = xml_add_tag_uint_val (xmlkey, "PRIMARY", id->is_primary);
+      if (!rc)
+	rc = xml_add_tag_uint_val (xmlkey, "REVOKED", id->is_revoked);
       if (rc)
 	return rc;
     }
@@ -266,7 +263,7 @@ static int
 xml_add_sig (gnutls_string * xmlkey, int ext, cdk_pkt_signature_t sig)
 {
   const char *algo, *s;
-  char tmp[32], keyid[16];
+  char keyid[16+1];
   unsigned int kid[2];
   int rc;
 
@@ -279,21 +276,18 @@ xml_add_sig (gnutls_string * xmlkey, int ext, cdk_pkt_signature_t sig)
   s = "  <SIGNATURE>\n";
   _gnutls_string_append_str (xmlkey, s);
 
-  sprintf (tmp, "%d", sig->version);
-  rc = xml_add_tag (xmlkey, "VERSION", tmp);
+  rc = xml_add_tag_uint_val (xmlkey, "VERSION", sig->version);
   if (rc)
     return rc;
 
   if (ext)
     {
-      sprintf (tmp, "%d", sig->sig_class);
-      rc = xml_add_tag (xmlkey, "SIGCLASS", tmp);
+      rc = xml_add_tag_uint_val (xmlkey, "SIGCLASS", sig->sig_class);
       if (rc)
 	return rc;
     }
 
-  sprintf (tmp, "%d", sig->flags.expired);
-  rc = xml_add_tag (xmlkey, "EXPIRED", tmp);
+  rc = xml_add_tag_uint_val (xmlkey, "EXPIRED", sig->flags.expired);
   if (rc)
     return rc;
 
@@ -304,10 +298,6 @@ xml_add_sig (gnutls_string * xmlkey, int ext, cdk_pkt_signature_t sig)
 	case GCRY_PK_DSA:
 	  algo = "DSA";
 	  break;
-	case GCRY_PK_ELG: /* FIXME: Is ElGamal needed? */
-	case GCRY_PK_ELG_E:
-	  algo = "ELG";
-	  break;
 	case GCRY_PK_RSA:
 	case GCRY_PK_RSA_E:
 	case GCRY_PK_RSA_S:
@@ -348,8 +338,7 @@ xml_add_sig (gnutls_string * xmlkey, int ext, cdk_pkt_signature_t sig)
 	return rc;
     }
 
-  sprintf (tmp, "%lu", (unsigned long)sig->timestamp);
-  rc = xml_add_tag (xmlkey, "CREATED", tmp);
+  rc = xml_add_tag_uint_val (xmlkey, "CREATED", sig->timestamp);
   if (rc)
     return rc;
 
@@ -380,12 +369,13 @@ int
 gnutls_openpgp_key_to_xml (gnutls_openpgp_key_t key,
 			   gnutls_datum_t * xmlkey, int ext)
 {
-  cdk_kbnode_t node, ctx = NULL;
+  cdk_kbnode_t node, ctx;
   cdk_packet_t pkt;
   char name[MAX_CN];
   size_t name_len;
   const char *s;
-  int idx = 0, rc = 0;
+  int idx;
+  int rc = 0;
   gnutls_string string_xml_key;
 
   if (!key || !xmlkey)
@@ -406,6 +396,7 @@ gnutls_openpgp_key_to_xml (gnutls_openpgp_key_t key,
   s = " <OPENPGPKEY>\n";
   _gnutls_string_append_str (&string_xml_key, s);
 
+  ctx = NULL;
   idx = 1;
   while ((node = cdk_kbnode_walk (key->knode, &ctx, 0)))
     {
@@ -415,7 +406,7 @@ gnutls_openpgp_key_to_xml (gnutls_openpgp_key_t key,
 	case CDK_PKT_PUBLIC_KEY:
 	  rc = xml_add_key (&string_xml_key, ext, pkt->pkt.public_key, 0);
 	  break;
-
+	  
 	case CDK_PKT_PUBLIC_SUBKEY:
 	  rc = xml_add_key (&string_xml_key, ext, pkt->pkt.public_key, 1);
 	  break;
